| Home | Libraries | People | FAQ | More

### Distributions

Arcsine Distribution
Bernoulli Distribution
Beta Distribution
Binomial Distribution
Cauchy-Lorentz Distribution
Chi Squared Distribution
Empirical Cumulative Distribution Function
Exponential Distribution
Extreme Value Distribution
F Distribution
Gamma (and Erlang) Distribution
Geometric Distribution
Hyperexponential Distribution
Hypergeometric Distribution
Inverse Chi Squared Distribution
Inverse Gamma Distribution
Inverse Gaussian (or Inverse Normal) Distribution
Kolmogorov-Smirnov Distribution
Laplace Distribution
Logistic Distribution
Log Normal Distribution
Negative Binomial Distribution
Noncentral Beta Distribution
Noncentral Chi-Squared Distribution
Noncentral F Distribution
Noncentral T Distribution
Normal (Gaussian) Distribution
Pareto Distribution
Poisson Distribution
Rayleigh Distribution
Skew Normal Distribution
Students t Distribution
Triangular Distribution
Uniform Distribution
Weibull Distribution

| Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)